@@ -2,7 +2,7 @@ import langchain.prompts as prompts
 
 summary_prompt = prompts.PromptTemplate(
     input_variables=["question", "context_str"],
-    template="Provide relevant information that will help answer a question from the context below. "
+    template="Provide relevant information that will help answer a question only from the context below. "
     "Summarize the information in an unbiased tone. Use direct quotes "
     "where possible. Do not directly answer the question. "
     'Reply with "Not applicable" if the context is irrelevant to the question. '
@@ -44,6 +44,6 @@ search_prompt = prompts.PromptTemplate(
     template="We want to answer the following question: {question} \n"
     "Provide three different targeted keyword searches (one search per line) "
     "that will find papers that help answer the question. Do not use boolean operators. "
-    "The current year is 2023.\n\n"
+    "Recent years are 2021, 2022, 2023.\n\n"
     "1.",
 )
